==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaYgdjLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 预告登记信息
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_ygdj_ls"
)
public class BaYgdjLs implements Serializable {


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String bdczl;

    @XmlAttribute
    @encrypt
    private String ywr;

    @XmlAttribute
    @Nullable
    private String ywrzjzl;

    @XmlAttribute
    @Nullable
    @encrypt
    private String ywrzjh;

    @XmlAttribute
    private String ygdjzl;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String tdsyqr;

    @XmlAttribute
    @Nullable
    private String ghyt;

    @XmlAttribute
    @Nullable
    private String fwxz;

    @XmlAttribute
    @Nullable
    private String fwjg;

    @XmlAttribute
    private String szc;

    @XmlAttribute
    private String zcs;

    @XmlAttribute
    private float jzmj;

    @XmlAttribute
    @Nullable
    private String qdjg;

    @XmlAttribute
    private String bdcdjzmh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    @id
    @Id
    private String id;

    @XmlAttribute
    @Nullable
    @ywh
    private String ssywh;

    @XmlAttribute
    @Nullable
    @ywh
    private String zxygywh;

    @XmlAttribute
    @Nullable
    private String zxygyy;

    @XmlAttribute
    @Nullable
    private Date zxsj;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String fwxzmc;

    @XmlAttribute
    private String jedw;

    @XmlAttribute
    private String dbfw;

    @XmlAttribute
    private String sfczjzhxz;

    /**
     * @author <a href="mailto:huming@gtmap.cn">huming</a>
     * @description 注销报文名称
     */
    private String zxbwmc;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getZxbwmc() {
        return zxbwmc;
    }

    public void setZxbwmc(String zxbwmc) {
        this.zxbwmc = zxbwmc;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getFwxzmc() {
        return fwxzmc;
    }

    public void setFwxzmc(String fwxzmc) {
        this.fwxzmc = fwxzmc;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getSfczjzhxz() {
        return sfczjzhxz;
    }

    public void setSfczjzhxz(String sfczjzhxz) {
        this.sfczjzhxz = sfczjzhxz;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getBdczl() {
        return bdczl;
    }

    public String getYwr() {
        return ywr;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public String getYgdjzl() {
        return ygdjzl;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public String getGhyt() {
        return ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public String getSzc() {
        return szc;
    }

    public String getZcs() {
        return zcs;
    }

    public float getJzmj() {
        return jzmj;
    }

    public String getQdjg() {
        return qdjg;
    }

    public String getBdcdjzmh() {
        return bdcdjzmh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setBdczl(String bdczl) {
        this.bdczl = bdczl;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public void setYgdjzl(String ygdjzl) {
        this.ygdjzl = ygdjzl;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public void setJzmj(float jzmj) {
        this.jzmj = jzmj;
    }

    public void setQdjg(String qdjg) {
        this.qdjg = qdjg;
    }

    public void setBdcdjzmh(String bdcdjzmh) {
        this.bdcdjzmh = bdcdjzmh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String scywh) {
        this.ssywh = ssywh;
    }


    public String getZxygywh() {
        return zxygywh;
    }

    public void setZxygywh(String zxygywh) {
        this.zxygywh = zxygywh;
    }

    public String getZxygyy() {
        return zxygyy;
    }

    public void setZxygyy(String zxygyy) {
        this.zxygyy = zxygyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }
}

==> realestate-supervise-common-1.1.0-20251208.011103-73-sources.jar: cn/gtmap/realestate/supervise/entity/BaYgdjLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 预告登记信息
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_ygdj_ls"
)
public class BaYgdjLs implements Serializable {


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String bdczl;

    @XmlAttribute
    @encrypt
    private String ywr;

    @XmlAttribute
    @Nullable
    private String ywrzjzl;

    @XmlAttribute
    @Nullable
    @encrypt
    private String ywrzjh;

    @XmlAttribute
    private String ygdjzl;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String tdsyqr;

    @XmlAttribute
    @Nullable
    private String ghyt;

    @XmlAttribute
    @Nullable
    private String fwxz;

    @XmlAttribute
    @Nullable
    private String fwjg;

    @XmlAttribute
    private String szc;

    @XmlAttribute
    private String zcs;

    @XmlAttribute
    private float jzmj;

    @XmlAttribute
    @Nullable
    private String qdjg;

    @XmlAttribute
    private String bdcdjzmh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    @id
    @Id
    private String id;

    @XmlAttribute
    @Nullable
    @ywh
    private String ssywh;

    @XmlAttribute
    @Nullable
    @ywh
    private String zxygywh;

    @XmlAttribute
    @Nullable
    private String zxygyy;

    @XmlAttribute
    @Nullable
    private Date zxsj;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String fwxzmc;

    @XmlAttribute
    private String jedw;

    @XmlAttribute
    private String dbfw;

    @XmlAttribute
    private String sfczjzhxz;

    /**
     * @author <a href="mailto:huming@gtmap.cn">huming</a>
     * @description 注销报文名称
     */
    private String zxbwmc;

    @sqlx
    private String sqlx;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 债务起始时间 */
    @XmlAttribute
    private Date zwqssj;

    /** 债务终止时间 */
    @XmlAttribute
    private Date zwzzsj;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getZxbwmc() {
        return zxbwmc;
    }

    public void setZxbwmc(String zxbwmc) {
        this.zxbwmc = zxbwmc;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getFwxzmc() {
        return fwxzmc;
    }

    public void setFwxzmc(String fwxzmc) {
        this.fwxzmc = fwxzmc;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getSfczjzhxz() {
        return sfczjzhxz;
    }

    public void setSfczjzhxz(String sfczjzhxz) {
        this.sfczjzhxz = sfczjzhxz;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getBdczl() {
        return bdczl;
    }

    public String getYwr() {
        return ywr;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public String getYgdjzl() {
        return ygdjzl;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public String getGhyt() {
        return ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public String getSzc() {
        return szc;
    }

    public String getZcs() {
        return zcs;
    }

    public float getJzmj() {
        return jzmj;
    }

    public String getQdjg() {
        return qdjg;
    }

    public String getBdcdjzmh() {
        return bdcdjzmh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setBdczl(String bdczl) {
        this.bdczl = bdczl;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public void setYgdjzl(String ygdjzl) {
        this.ygdjzl = ygdjzl;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public void setJzmj(float jzmj) {
        this.jzmj = jzmj;
    }

    public void setQdjg(String qdjg) {
        this.qdjg = qdjg;
    }

    public void setBdcdjzmh(String bdcdjzmh) {
        this.bdcdjzmh = bdcdjzmh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String scywh) {
        this.ssywh = ssywh;
    }


    public String getZxygywh() {
        return zxygywh;
    }

    public void setZxygywh(String zxygywh) {
        this.zxygywh = zxygywh;
    }

    public String getZxygyy() {
        return zxygyy;
    }

    public void setZxygyy(String zxygyy) {
        this.zxygyy = zxygyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public Date getZwqssj() {
        return zwqssj;
    }

    public void setZwqssj(Date zwqssj) {
        this.zwqssj = zwqssj;
    }

    public Date getZwzzsj() {
        return zwzzsj;
    }

    public void setZwzzsj(Date zwzzsj) {
        this.zwzzsj = zwzzsj;
    }
}
